@@ -377,6 +377,9 @@ INVALIDPARAMETERVALUE_UNSUPPORTEDSCALEPARAM = 'InvalidParameterValue.UnSupported
 # 不支持的流协议
 INVALIDPARAMETERVALUE_UNSUPPORTEDSTREAMPROTOCOL = 'InvalidParameterValue.UnsupportedStreamProtocol'
 
+# 查询的通道数量不能超过3000个
+LIMITEXCEEDED_CHANNELNUMEXCEEDED = 'LimitExceeded.ChannelNumExceeded'
+
 # 时间片段不存在
 MISSINGPARAMETER_EMPTYTIMESECTION = 'MissingParameter.EmptyTimeSection'
 
@@ -398,6 +401,9 @@ OPERATIONDENIED_CONCURRENTDOWNLOADSOVERLIMIT = 'OperationDenied.ConcurrentDownlo
 # 链接数受限
 OPERATIONDENIED_CONNECTSLIMITZERO = 'OperationDenied.ConnectsLimitZero'
 
+# 新增组织树失败，超出组织树的最大深度
+OPERATIONDENIED_EXCEEDEDMAXIMUMDEPTH = 'OperationDenied.ExceededMaximumDepth'
+
 # 资源不可达，该资源不属于该地域
 REGIONERROR_RESOURCEUNREACHABLE = 'RegionError.ResourceUnreachable'
 
